@@ -21,10 +21,10 @@ class MplDrawer(
     Drawer
 ):
     """
-  Real time plotting base class
+    Real time plotting base class
 
-  for Matplotlib
-  """
+    for Matplotlib
+    """
 
     # @drop_unused_kws
     def __init__(
@@ -32,23 +32,23 @@ class MplDrawer(
         *,
         default_delta: float = 1 / 120,
         render: bool = True,
-        placement: Tuple[int, int] = (0, 0),
+        placement: Tuple[int, int] = None,
         **kwargs,
     ):
         """
 
-    :param default_delta:
-    :param render:
-    :param placement:
-    :param kwargs:"""
-        super().__init__()
+        :param default_delta:
+        :param render:
+        :param placement:
+        :param kwargs:"""
+        super().__init__(**kwargs)
         self.fig = None
 
         if not render:
             return
 
         if default_delta is None:  # Zero still passes
-            default_delta = 3e-7
+            default_delta = 1 / 120
 
         self._default_delta = default_delta
         self.n = 0
@@ -72,6 +72,8 @@ if self.fig is None:
 """
 
     def draw(self, data: Any, delta: float = None):
+        """
+        """
         if not self.fig:
             raise NotImplementedError(
                 "Figure was not instantiated check specialisation of MplDrawer"
@@ -81,11 +83,11 @@ if self.fig is None:
 
         pyplot.draw()
 
-        if self.n <= 1:
+        if self.n <= 1 and self.placement:
             self.move_figure(self.fig, *self.placement)
         self.n += 1
 
-        if delta:
+        if delta:  # TODO: ALLOW FOR ASYNC DRAWING
             pyplot.pause(delta)
         elif self._default_delta:
             pyplot.pause(self._default_delta)
@@ -93,8 +95,8 @@ if self.fig is None:
     @staticmethod
     def move_figure(figure: pyplot.Figure, x: int = 0, y: int = 0):
         r"""
-    Move figure's upper left corner to pixel (x, y)
-    """
+        Move figure's upper left corner to pixel (x, y)
+        """
         backend = matplotlib.get_backend()
         if hasattr(figure.canvas.manager, "window"):
             window = figure.canvas.manager.window
@@ -110,31 +112,37 @@ if self.fig is None:
     def __enter__(self):
         return self
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def close(self):
+        if self._verbose:
+            print("mlpdrawer close was called")
         if self.fig:
             pyplot.close(self.fig)
 
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.close()
+
+    def __del__(self):
+        self.close()
+
     @abstractmethod
     def _draw(self, data: Any) -> None:
         """
 
-    :param data:
-    :type data:
-    :param delta:
-    :type delta:"""
+        :param data:
+        :type data:
+        """
         raise NotImplementedError
 
 
 class MockDrawer(MplDrawer):
     """
-  Mock for drawer, accepts data but draws nothing
-  """
+    Mock for drawer, accepts data but draws nothing
+    """
 
     def _draw(self, data: Sequence) -> None:
         """
 
-    :param data:
-    :type data:
-    :param delta:
-    :type delta:"""
+        :param data:
+        :type data:
+        """
         pass
