@@ -5,14 +5,16 @@ from shutil import rmtree
 __author__ = "Christian Heider Nielsen"
 __doc__ = ""
 
+from draugr import IgnoreInterruptSignal
+
 
 def main(keep_alive: bool = True) -> str:
     """
 
-  :param keep_alive:
-  :type keep_alive:
-  :return:
-  :rtype:"""
+    :param keep_alive:
+    :type keep_alive:
+    :return:
+    :rtype:"""
     from draugr.torch_utilities import launch_tensorboard
     from contextlib import suppress
     from time import sleep
@@ -55,7 +57,7 @@ def main(keep_alive: bool = True) -> str:
 
     if keep_alive:
         print(f"tensorboard address: {address} for log_dir {log_dir}")
-        with suppress(KeyboardInterrupt):
+        with IgnoreInterruptSignal():
             while True:
                 sleep(10)
 
