@@ -9,7 +9,7 @@ __doc__ = r"""
 
 import os
 from pathlib import Path
-from typing import Sequence, Tuple, Union, Iterable
+from typing import Iterable, Union
 
 __all__ = ["build_flat_dataset"]
 
@@ -24,11 +24,11 @@ def build_flat_dataset(
 ) -> dict:
     """
 
-  :param directory:
-  :param extensions:
-  :param is_valid_file:
-  :return:
-  """
+    :param directory:
+    :param extensions:
+    :param is_valid_file:
+    :return:
+    """
     if not isinstance(directory, Path):
         directory = Path(directory)
 
@@ -44,6 +44,8 @@ def build_flat_dataset(
     if extensions is not None:
 
         def is_valid_file(x: Union[Path, str]) -> bool:
+            """
+            """
             return str(x) in extensions
 
     elif is_valid_file is None:
@@ -64,6 +66,8 @@ def build_flat_dataset(
 if __name__ == "__main__":
 
     def absa():
+        """
+        """
         from draugr.visualisation import indent_lines
         from draugr.numpy_utilities.datasets.splitting import Split
 
