@@ -1,8 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 import contextlib
+import signal
 from time import sleep
-from typing import Iterable, MutableSequence
+from typing import Callable, Iterable, MutableSequence
+
+from pynput.keyboard import KeyCode
 
 from draugr.python_utilities.styling import sprint
 
@@ -10,7 +13,7 @@ __author__ = "Christian Heider Nielsen"
 __doc__ = ""
 
 from warg import GDKC, drop_unused_kws, passes_kws_to
-from pynput import keyboard
+
 
 # import keyboard
 
@@ -19,55 +22,64 @@ __all__ = ["add_early_stopping_key_combination", "CaptureEarlyStop"]
 
 @drop_unused_kws
 def add_early_stopping_key_combination(
-    callbacks: callable = None, has_x_server: bool = True, verbose: bool = False
-) -> keyboard.Listener:
+    *callbacks: Iterable[Callable], has_x_server: bool = True, verbose: bool = False
+):  # -> keyboard.Listener:
+
     """
 
-:param callbacks:
-:param has_x_server:
-:param verbose:
-:return:"""
+  :param callbacks:
+  :param has_x_server:
+  :param verbose:
+  :return:"""
     if not has_x_server:
         return
 
-    COMBINATIONS = [
+    from pynput import keyboard
+
+    combinations = [
         {keyboard.Key.ctrl, keyboard.KeyCode(char="c")},
         {keyboard.Key.ctrl, keyboard.KeyCode(char="d")},
         {keyboard.Key.shift, keyboard.Key.alt, keyboard.KeyCode(char="s")},
         {keyboard.Key.shift, keyboard.Key.alt, keyboard.KeyCode(char="S")},
+        {
+            keyboard.Key.ctrl_l,
+            keyboard.KeyCode(char="c"),
+        },  # windows is annoying, does something weird translation....
+        {keyboard.Key.ctrl_l, keyboard.KeyCode(char="d")},
+        {KeyCode.from_char("\x04")},  # ctrl+d on windows
+        {KeyCode.from_char("\x03")},  # ctrl+d on windows
     ]
 
-    CALLBACKS: MutableSequence = []
     # The currently active modifiers
     current = set()
 
     # keyboard.add_hotkey(key, callback)
-    if callbacks is not None:
-        if isinstance(callbacks, Iterable):
-            CALLBACKS.extend(callbacks)
-        else:
-            CALLBACKS.append(callbacks)
+    assert all([isinstance(cb, Callable) for cb in callbacks])
     if verbose:
         sprint(
-            f"\n\nPress any of:\n{COMBINATIONS}\n for early stopping\n",
+            f"\n\nPress any of:\n{combinations}\n for early stopping\n",
             color="red",
             bold=True,
             highlight=True,
         )
 
     def on_press(key):
-        if any([key in COMBO for COMBO in COMBINATIONS]):
+        """
+    """
+        if any([key in COMBO for COMBO in combinations]):
             if verbose:
                 print(f"Adding key {key}")
             current.add(key)
-            if any(all(k in current for k in COMBO) for COMBO in COMBINATIONS):
-                for clbck in CALLBACKS:
+            if any(all(k in current for k in COMBO) for COMBO in combinations):
+                for clbck in callbacks:
                     if verbose:
                         print(f"Calling {clbck}")
                     clbck()
 
     def on_release(key):
-        if any([key in combo for combo in COMBINATIONS]):
+        """
+    """
+        if any([key in combo for combo in combinations]):
             if key in current:
                 if verbose:
                     print(f"Removing key {key}")
@@ -78,7 +90,7 @@ def add_early_stopping_key_combination(
 
 class CaptureEarlyStop(contextlib.AbstractContextManager):
     """
-Context for early stopping a loop"""
+  Context for early stopping a loop"""
 
     @passes_kws_to(add_early_stopping_key_combination)
     def __init__(self, *args, **kwargs):
@@ -97,10 +109,14 @@ Context for early stopping a loop"""
 if __name__ == "__main__":
 
     def c():
+        """
+    """
         print("start")
         RUN = True
 
         def stop_loop():
+            """
+      """
             global RUN
             RUN = False
 
@@ -110,6 +126,8 @@ if __name__ == "__main__":
         print("done")
 
     def b():  # DOES NOT WORK!
+        """
+    """
         print("start2")
         with CaptureEarlyStop(GDKC(exit, code=0)) as _:
             while True:
