@@ -3,9 +3,10 @@
 
 __author__ = "Christian Heider Nielsen"
 
-import pathlib
 
-with open(pathlib.Path(__file__).parent / "README.md", "r") as this_init_file:
+from pathlib import Path
+
+with open(Path(__file__).parent / "README.md", "r") as this_init_file:
     __doc__ = this_init_file.read()
 
 from .system import *
