@@ -7,9 +7,10 @@ __doc__ = r"""
            Created on 09/10/2019
            """
 
-import pathlib
 
-with open(pathlib.Path(__file__).parent / "README.md", "r") as this_init_file:
+from pathlib import Path
+
+with open(Path(__file__).parent / "README.md", "r") as this_init_file:
     __doc__ += this_init_file.read()
 
 from .non_sequential_dataset import *
