@@ -22,10 +22,10 @@ __all__ = ["to_tensor_generator", "batch_generator_torch", "to_device_iterator"]
 def to_tensor_generator(iterable: Iterable, preload_next: bool = False, **kwargs):
     """
 
-:param iterable:
-:param preload_next:
-:param kwargs:
-:return:"""
+    :param iterable:
+    :param preload_next:
+    :param kwargs:
+    :return:"""
     if preload_next:
         iterable_iter = iter(iterable)
         current = to_tensor(next(iterable_iter), **kwargs)
@@ -45,9 +45,8 @@ def to_device_iterator(
 ) -> Tuple:
     """
 
-:param data_iterator:
-:param device:
-"""
+    :param data_iterator:
+    :param device:"""
     if isinstance(data_iterator, Iterable):
         data_iterator = iter(data_iterator)
     try:
@@ -63,12 +62,11 @@ def batch_generator_torch(
 ) -> DataLoader:
     """
 
-:param sized:
-:param mini_batches:
-:param shuffle:
-:param kwargs:
-:return:
-"""
+    :param sized:
+    :param mini_batches:
+    :param shuffle:
+    :param kwargs:
+    :return:"""
 
     dataset = NonSequentialDataset(sized)
     return DataLoader(
@@ -83,7 +81,8 @@ if __name__ == "__main__":
     from draugr import inner_map
 
     def s():
-
+        """
+        """
         a = iter(numpy.random.sample((5, 5, 5)))
         for a in to_device_iterator(a, "cpu"):
             d, *_ = a
@@ -91,6 +90,8 @@ if __name__ == "__main__":
             print(type(d))
 
     def sdiaj():
+        """
+        """
         # a = numpy.random.sample((5, 5, 5))
         from draugr.torch_utilities.datasets import RandomDataset
 
@@ -102,6 +103,8 @@ if __name__ == "__main__":
                 print(type(d))
 
     def asijda():
+        """
+        """
         a_transform = transforms.Compose(
             [
                 transforms.ToPILImage("RGB"),
