@@ -9,23 +9,25 @@ __doc__ = r"""
 
 __all__ = ["save_config", "ensure_directory_exist"]
 
-import pathlib
+
 import shutil
 
+from pathlib import Path
 
-def save_config(config_save_path: pathlib.Path, config_file_path: pathlib.Path) -> None:
+
+def save_config(config_save_path: Path, config_file_path: Path) -> None:
     """
 
-  :param config_save_path:
-  :param config_file_path:
-  :return:"""
+    :param config_save_path:
+    :param config_file_path:
+    :return:"""
     shutil.copyfile(str(config_file_path), str(config_save_path))
 
 
-def ensure_directory_exist(model_path: pathlib.Path) -> None:
+def ensure_directory_exist(model_path: Path) -> None:
     """
 
-  :param model_path:
-  :return:"""
+    :param model_path:
+    :return:"""
     if not model_path.exists():
         model_path.mkdir(parents=True)
