@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-import pathlib
+
 from contextlib import suppress
 from typing import Any, Iterable, Sequence, Union
 
@@ -42,6 +42,8 @@ Created on 27/04/2019
 """
 __all__ = ["TensorBoardPytorchWriter"]
 
+from pathlib import Path
+
 
 class TensorBoardPytorchWriter(
     Writer,
@@ -57,7 +59,7 @@ class TensorBoardPytorchWriter(
     EmbedWriterMixin,
 ):
     """
-  Provides a pytorch-tensorboard-implementation writer interface"""
+    Provides a pytorch-tensorboard-implementation writer interface"""
 
     @passes_kws_to(SummaryWriter.add_embedding)
     def embed(
@@ -71,16 +73,15 @@ class TensorBoardPytorchWriter(
     ) -> None:
         """
 
-BORKED!
+        BORKED!
 
-:param tag:
-:param response:
-:param metadata:
-:param label_img:
-:param step:
-:param kwargs:
-:return:
-"""
+        :param tag:
+        :param response:
+        :param metadata:
+        :param label_img:
+        :param step:
+        :param kwargs:
+        :return:"""
         try:
             self.writer.add_embedding(
                 response,
@@ -97,16 +98,15 @@ BORKED!
     @passes_kws_to(Writer.__init__)
     def __init__(
         self,
-        path: Union[str, pathlib.Path] = pathlib.Path.cwd() / "Logs",
+        path: Union[str, Path] = Path.cwd() / "Logs",
         summary_writer_kws=None,
         **kwargs,
     ):
         """
 
-:param path:
-:param summary_writer_kws:
-:param kwargs:
-"""
+        :param path:
+        :param summary_writer_kws:
+        :param kwargs:"""
         super().__init__(**kwargs)
 
         if summary_writer_kws is None:
@@ -119,12 +119,11 @@ BORKED!
     def instance(self, instance: dict, metrics: dict) -> None:
         """
 
-Not finished!
+        Not finished!
 
-:param instance:
-:param metrics:
-:return:
-"""
+        :param instance:
+        :param metrics:
+        :return:"""
         self.writer.add_hparams(instance, metrics)
 
     @drop_unused_kws
@@ -139,12 +138,12 @@ Not finished!
     ) -> None:
         """
 
-    :param tag:
-    :param predictions:
-    :param truths:
-    :param step:
-    :param kwargs:
-    """
+        :param tag:
+        :param predictions:
+        :param truths:
+        :param step:
+        :param kwargs:
+        """
         self.writer.add_pr_curve(
             tag,
             to_tensor(truths, device="cpu"),
@@ -158,14 +157,14 @@ Not finished!
     def figure(self, tag: str, figure: Figure, step: int, **kwargs) -> None:
         """
 
-    :param tag:
-    :type tag:
-    :param figure:
-    :type figure:
-    :param step:
-    :type step:
-    :param kwargs:
-    :type kwargs:"""
+        :param tag:
+        :type tag:
+        :param figure:
+        :type figure:
+        :param step:
+        :type step:
+        :param kwargs:
+        :type kwargs:"""
         self.writer.add_figure(tag, figure, global_step=step, **kwargs)
 
     @drop_unused_kws
@@ -186,25 +185,25 @@ Not finished!
     ) -> None:
         """
 
-        :param sample_rate:
-        :param n_fft:
-        :param step_size:
-    :param tag:
-    :type tag:
-    :param values:
-    :type values:
-    :param step:
-    :type step:
-    :param x_labels:
-    :type x_labels:
-    :param y_label:
-    :type y_label:
-    :param x_label:
-    :type x_label:
-    :param plot_kws:
-    :type plot_kws:
-    :param kwargs:
-    :type kwargs:"""
+            :param sample_rate:
+            :param n_fft:
+            :param step_size:
+        :param tag:
+        :type tag:
+        :param values:
+        :type values:
+        :param step:
+        :type step:
+        :param x_labels:
+        :type x_labels:
+        :param y_label:
+        :type y_label:
+        :param x_label:
+        :type x_label:
+        :param plot_kws:
+        :type plot_kws:
+        :param kwargs:
+        :type kwargs:"""
         if plot_kws is None:
             plot_kws = {}
         fig = pyplot.figure()
@@ -247,22 +246,22 @@ pyplot.title(tag)
     ) -> None:
         """
 
-    :param x_label:
-    :type x_label:
-    :param tag:
-    :type tag:
-    :param values:
-    :type values:
-    :param step:
-    :type step:
-    :param value_error:
-    :type value_error:
-    :param x_labels:
-    :type x_labels:
-    :param y_label:
-    :type y_label:
-    :param kwargs:
-    :type kwargs:"""
+        :param x_label:
+        :type x_label:
+        :param tag:
+        :type tag:
+        :param values:
+        :type values:
+        :param step:
+        :type step:
+        :param value_error:
+        :type value_error:
+        :param x_labels:
+        :type x_labels:
+        :param y_label:
+        :type y_label:
+        :param kwargs:
+        :type kwargs:"""
         fig = pyplot.figure()
         ind = numpy.arange(len(values))
         im = pyplot.bar(ind, values, yerr=value_error)
@@ -294,22 +293,22 @@ pyplot.title(tag)
     ) -> None:
         """
 
-    :param x_label:
-    :type x_label:
-    :param plot_kws:
-    :type plot_kws:
-    :param tag:
-    :type tag:
-    :param values:
-    :type values:
-    :param step:
-    :type step:
-    :param x_labels:
-    :type x_labels:
-    :param y_label:
-    :type y_label:
-    :param kwargs:
-    :type kwargs:"""
+        :param x_label:
+        :type x_label:
+        :param plot_kws:
+        :type plot_kws:
+        :param tag:
+        :type tag:
+        :param values:
+        :type values:
+        :param step:
+        :type step:
+        :param x_labels:
+        :type x_labels:
+        :param y_label:
+        :type y_label:
+        :param kwargs:
+        :type kwargs:"""
         if plot_kws is None:
             plot_kws = {}
         fig = pyplot.figure()
@@ -335,16 +334,16 @@ pyplot.title(tag)
     ) -> None:
         """
 
-    :param tag:
-    :type tag:
-    :param values:
-    :type values:
-    :param step:
-    :type step:
-    :param bins:
-    :type bins:
-    :param kwargs:
-    :type kwargs:"""
+        :param tag:
+        :type tag:
+        :param values:
+        :type values:
+        :param step:
+        :type step:
+        :param bins:
+        :type bins:
+        :param kwargs:
+        :type kwargs:"""
         self.writer.add_histogram(tag, values, global_step=step, bins=bins, **kwargs)
 
     def _scalar(self, tag: str, value: float, step: int) -> None:
@@ -360,11 +359,11 @@ pyplot.title(tag)
     ) -> None:
         """
 
-        :param verbose:
-    :param model:
-    :type model:
-    :param input_to_model:
-    :type input_to_model:"""
+            :param verbose:
+        :param model:
+        :type model:
+        :param input_to_model:
+        :type input_to_model:"""
         self.writer.add_graph(model, input_to_model, verbose)
 
     def _close(self, exc_type=None, exc_val=None, exc_tb=None):
@@ -384,24 +383,24 @@ pyplot.title(tag)
     ) -> None:
         """
 
-    :param tag:
-    :type tag:
-    :param data:
-    :type data:
-    :param step:
-    :type step:
-    :param data_formats:
-    :type data_formats:
-    :param kwargs:
-    :type kwargs:"""
+        :param tag:
+        :type tag:
+        :param data:
+        :type data:
+        :param step:
+        :type step:
+        :param data_formats:
+        :type data_formats:
+        :param kwargs:
+        :type kwargs:"""
         self.writer.add_image(tag, data, step, dataformats=data_formats, **kwargs)
 
     @property
     def writer(self) -> SummaryWriter:
         """
 
-    :return:
-    :rtype:"""
+        :return:
+        :rtype:"""
         if not hasattr(self, "_writer") or not self._writer:
             self._writer = SummaryWriter(str(self._log_dir), **self._summary_writer_kws)
             if self._verbose:
