@@ -6,10 +6,10 @@ __doc__ = r"""
 
            Created on 11-01-2021
            """
+from pathlib import Path
 
-import pathlib
 
-with open(pathlib.Path(__file__).parent / "README.md", "r") as this_init_file:
+with open(Path(__file__).parent / "README.md", "r") as this_init_file:
     __doc__ += this_init_file.read()
 
 from .spectral_plotting import *
