@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 import logging
-import pathlib
+
 import sys
 
 from apppath import ensure_existence
@@ -15,6 +15,7 @@ Created on 27/04/2019
 @author: cnheider
 """
 __all__ = ["LogWriter"]
+from pathlib import Path
 
 
 class LogWriter(Writer):
@@ -25,17 +26,16 @@ class LogWriter(Writer):
 
     @staticmethod
     def get_logger(
-        path: pathlib.Path = pathlib.Path.cwd() / "0.log",
-        write_to_std_out: bool = False,
+        path: Path = Path.cwd() / "0.log", write_to_std_out: bool = False,
     ) -> logging.Logger:
         """
 
-    :param path:
-    :type path:
-    :param write_to_std_out:
-    :type write_to_std_out:
-    :return:
-    :rtype:"""
+        :param path:
+        :type path:
+        :param write_to_std_out:
+        :type write_to_std_out:
+        :return:
+        :rtype:"""
         ensure_existence(path, declare_file=True, overwrite_on_wrong_type=True)
 
         handlers = [logging.FileHandler(filename=str(path))]
