@@ -14,8 +14,7 @@ from typing import Any, Sequence
 
 class EmbedWriterMixin(ABC):
     """
-Writer mixin that provides an interface for 'writing' embeds/projections(2d,3d) for interactive visualisation
-"""
+    Writer mixin that provides an interface for 'writing' embeds/projections(2d,3d) for interactive visualisation"""
 
     @abstractmethod
     def embed(
@@ -28,13 +27,12 @@ Writer mixin that provides an interface for 'writing' embeds/projections(2d,3d)
         **kwargs
     ) -> None:
         """
-    eg. visualising for projections in lower dimensional space
+            eg. visualising for projections in lower dimensional space
 
-:param tag:
-:type tag:
-:param step:
-:type step:
-:param kwargs:
-:type kwargs:
-"""
+        :param tag:
+        :type tag:
+        :param step:
+        :type step:
+        :param kwargs:
+        :type kwargs:"""
         raise NotImplementedError
