@@ -16,21 +16,11 @@ from warg import drop_unused_kws
 
 class InstantiationWriterMixin(ABC):
     """
-  Writer mixin that provides an interface for 'writing' instantiation"""
+    Writer mixin that provides an interface for 'writing' instantiation"""
 
     @drop_unused_kws
     @abstractmethod
     def instance(self, instance: Mapping, metrics: Mapping) -> None:
         """
-
-    :param tag:
-    :type tag:
-    :param data:
-    :type data:
-    :param step:
-    :type step:
-    :param dataformats:
-    :type dataformats:
-    :param kwargs:
-    :type kwargs:"""
+    """
         raise NotImplementedError
