@@ -9,14 +9,12 @@ __doc__ = r"""
            """
 __all__ = ["PrecisionRecallCurveWriterMixin"]
 
-from typing import Mapping
-
 from warg import drop_unused_kws
 
 
 class PrecisionRecallCurveWriterMixin(ABC):
     """
-  Writer mixin that provides an interface for 'writing' instantiation"""
+    Writer mixin that provides an interface for 'writing' instantiation"""
 
     @drop_unused_kws
     @abstractmethod
@@ -30,14 +28,5 @@ class PrecisionRecallCurveWriterMixin(ABC):
     ) -> None:
         """
 
-    :param tag:
-    :type tag:
-    :param data:
-    :type data:
-    :param step:
-    :type step:
-    :param dataformats:
-    :type dataformats:
-    :param kwargs:
-    :type kwargs:"""
+        """
         raise NotImplementedError
